@@ -30,7 +30,7 @@ import sys
 
 import gobject
 
-HAVE_2_6 = gobject.pygtk_version[:2] == (2, 6)
+HAVE_2_6 = gobject.pygtk_version[:2] <= (2, 6)
 
 # When we can depend on 2.8 clean this up, so ClassInittable does not
 # need to be tied to GObjectMeta, since it doesn't need to be a GObject
@@ -135,6 +135,11 @@ class PropertyMeta(_GObjectClassInittableMetaType):
         self.__gproperties__ = {}
         self.__gsignals__ = {}
 
+    def __call__(self, *args, **kwargs):
+        rv = super(PropertyMeta, self).__call__(*args, **kwargs)
+        rv.__post_init__()
+        return rv
+
 class PropertyObject(object):
     """
     I am an object which maps GObject properties to attributes
@@ -202,6 +207,14 @@ class PropertyObject(object):
 
     __class_init__ = classmethod(__class_init__)
 
+    def __post_init__(self):
+        """
+        A hook which is called after the constructor is called.
+        It's mainly here to workaround
+        http://bugzilla.gnome.org/show_bug.cgi?id=425501
+        so you can set properties at construction time
+        """
+
     def _set(self, name, value):
         func = getattr(self, 'prop_set_%s' % name, None)
         if callable(func) and func:
@@ -238,7 +251,7 @@ def gsignal(name, *args, **kwargs):
     @param args:     types for signal parameters,
       if the first one is a string 'override', the signal will be
       overridden and must therefor exists in the parent GObject.
-    @keyword flags: One of the following:
+    @keyword flags: A combination of;
       - gobject.SIGNAL_RUN_FIRST
       - gobject.SIGNAL_RUN_LAST
       - gobject.SIGNAL_RUN_CLEANUP
@@ -279,7 +292,7 @@ def _max(c):
     return 2 ** ((8 * struct.calcsize(c)) - 1) - 1
 
 _MAX_VALUES = {int : _max('i'),
-               float : _max('f'),
+               float: float(2**1024 - 2**971),
                long : _max('l') }
 _DEFAULT_VALUES = {str : '', float : 0.0, int : 0, long : 0L}
 
@@ -294,7 +307,7 @@ def gproperty(name, ptype, default=None, nick='', blurb='',
     @param default:  default value
     @param nick:     short description
     @param blurb:    long description
-    @param flags:    parameter flags, one of:
+    @param flags:    parameter flags, a combination of:
       - PARAM_READABLE
       - PARAM_READWRITE
       - PARAM_WRITABLE
@@ -347,11 +360,8 @@ def gproperty(name, ptype, default=None, nick='', blurb='',
     else:
         raise NotImplementedError("type %r" % ptype)
 
-    if flags not in (gobject.PARAM_READABLE, gobject.PARAM_READWRITE,
-                     gobject.PARAM_WRITABLE, gobject.PARAM_CONSTRUCT,
-                     gobject.PARAM_CONSTRUCT_ONLY,
-                     gobject.PARAM_LAX_VALIDATION):
-        raise TypeError("invalid flag value: %r" % flags)
+    if flags < 0 or flags > 32:
+        raise TypeError("invalid flag value: %r" % (flags,))
 
     frame = sys._getframe(1)
     try:
